@@ -1,6 +1,6 @@
 # Author: Babak Naimi, naimi.b@gmail.com
-# Date of last update :  Feb 2024
-# Version 1.1
+# Date of last update :  March 2024
+# Version 1.2
 # Licence GPL v3
 #--------------
 
@@ -11,7 +11,7 @@
   x <- p[aj]
   w <- which(apply(x,1,function(x) all(!is.na(x))))
   if (length(w) > 0) {
-    if (length(w) == 1) aj
+    if (length(w) == 1) aj[w]
     else aj[sample(w,1)]
   } else NA
 }
