@@ -1,6 +1,6 @@
 # Author: Babak Naimi, naimi.b@gmail.com
-# Date (last uodate):  May. 2020
-# Version 2.6
+# Date (last uodate):  Feb. 2024
+# Version 2.7
 # Licence GPL v3
 
 
@@ -58,7 +58,12 @@ setMethod('getmethodNames', signature(w='ANY'),
             if (missing(w)) w <- 'sdm'
             if (missing(alt)) alt <- TRUE
             if (!.sdmOptions$getOption('sdmLoaded')) .addMethods()
-            if (w == 'sdm') .sdmMethods$getMethodNames(alt=alt)
+            if (w == 'sdm') {
+              m <- .sdmMethods$getMethodNames(alt=alt)
+              
+              if (is.list(m)) data.frame(Methods=names(m),Aliases=sapply(m,function (x) paste(x,collapse = ', ')))
+              else m
+            }
           }
 )
 
@@ -149,7 +154,7 @@ setMethod('getmethodNames', signature(w='ANY'),
   }
   #-----
   
-  if (class(fitFunction) == "character") {
+  if (inherits(fitFunction,"character")) {
     if (length(strsplit(fitFunction,'::')[[1]]) == 2) fitFunction <- strsplit(fitFunction,'::')[[1]][2]
     
     if (exists(fitFunction,mode='function')) {
@@ -162,7 +167,7 @@ setMethod('getmethodNames', signature(w='ANY'),
         # when environment if attached, the conflict with the existing object in .GlobalEnv should be resolved!
       }
       m@fitFunction <- eval(parse(text=paste("function(params) {do.call(",fitFunction,",params)}")))
-    } else if (length(strsplit(fitFunction,':::')[[1]]) == 2 && class(eval(parse(text=fitFunction))) == 'function') {
+    } else if (length(strsplit(fitFunction,':::')[[1]]) == 2 && inherits(eval(parse(text=fitFunction)),'function')) {
       if (!exists(strsplit(fitFunction,':::')[[1]][2],mode='function')) {
         m@fitFunction <- eval(parse(text=paste("function(params) {do.call(",strsplit(fitFunction,':::')[[1]][2],",params)}")))
       } else {
@@ -176,7 +181,7 @@ setMethod('getmethodNames', signature(w='ANY'),
       m@fitFunction <- eval(parse(text=paste("function(params) {do.call(",fitFunction,",params)}")))
     } else stop('fitFunction cannot be identified!')
     
-  } else if (class(fitFunction) == 'function') {
+  } else if (inherits(fitFunction,'function')) {
     if (is.null(m@.temp.env)) m@.temp.env <- new.env()
     if (!paste(m@name,'_fit',sep='') %in% ls(envir=m@.temp.env)) fn <-paste(m@name,'_fit',sep='') ####
     else stop('the user defined function in fitFunction cannot be registered because an object with a similar name exists in the container!')
@@ -187,7 +192,7 @@ setMethod('getmethodNames', signature(w='ANY'),
   #---------
   
   if (!is.null(predictFunction)) {
-    if (class(predictFunction) == "character") {
+    if (inherits(predictFunction,"character")) {
       if (length(strsplit(predictFunction,'::')[[1]]) == 2) predictFunction <- strsplit(predictFunction,'::')[[1]][2]
       if (exists(predictFunction,mode='function')) {
         if (environmentName(environment(get(predictFunction))) == "R_GlobalEnv") {
@@ -198,7 +203,7 @@ setMethod('getmethodNames', signature(w='ANY'),
           # when environment if attached, the conflict with the existing object in .GlobalEnv should be resolved!
         }
         m@predictFunction <- eval(parse(text=paste("function(params) {do.call(",predictFunction,",params)}")))
-      } else if (length(strsplit(predictFunction,':::')[[1]]) == 2 && class(eval(parse(text=predictFunction))) == 'function') {
+      } else if (length(strsplit(predictFunction,':::')[[1]]) == 2 && inherits(eval(parse(text=predictFunction)),'function')) {
         if (!exists(strsplit(predictFunction,':::')[[1]][2],mode='function')) {
           m@predictFunction <- eval(parse(text=paste("function(params) {do.call(",strsplit(predictFunction,':::')[[1]][2],",params)}")))
         } else {
@@ -211,7 +216,7 @@ setMethod('getmethodNames', signature(w='ANY'),
       } else if (!Installed) {
         m@predictFunction <- eval(parse(text=paste("function(params) {do.call(",predictFunction,",params)}")))
       } else stop('predictFunction cannot be identified!')
-    } else if (class(predictFunction) == 'function') {
+    } else if (inherits(predictFunction,'function')) {
       if (is.null(m@.temp.env)) m@.temp.env <- new.env()
       if (!paste(m@name,'_predict',sep='') %in% ls(envir=m@.temp.env)) fn <-paste(m@name,'_predict',sep='') ####
       else stop('the user defined function in predictFunction cannot be registered because an object with a similar name exists in the container!')
@@ -245,159 +250,7 @@ setMethod('getmethodNames', signature(w='ANY'),
   
   m
 }
-# 
-# 
-# .create.sdmCorrelativeMethod <- function(name,packages=NULL,modelTypes=NULL,fitParams,fitSettings=NULL,settingRules=NULL,fitFunction,predictParams=NULL,predictSettings=NULL,predictFunction=NULL,tuneParams=NULL,metadata=NULL,...) {
-#   m <- new('sdmCorrelativeMethod',name=name[1])
-#   if (length(name) > 1) m@aliases <- name[2:length(name)]
-#   if (!is.null(packages) && is.character(packages)) {
-#     m@packages <- packages
-#     w <- rep(FALSE,length(m@packages))
-#     for (i in seq_along(m@packages)) w[i] <- require(m@packages[i],character.only=TRUE)
-#     if (!all(w)) print(paste('warning: packages (',paste(m@packages[!w],collapse=', '),') need to be installed to get this method working!',sep=''))
-#   } else m@packages <- NULL
-#   
-#   if (!is.null(modelTypes)) {
-#     modelTypes <- tolower(modelTypes)
-#     for (i in 1:length(modelTypes)) {
-#       if (modelTypes[i] %in% c('po','presenceonly','presence-only','presence')) {
-#         modelTypes[i] <- 'po'
-#       } else if (modelTypes[i] %in% c('pa','presenceabsence','presence-absence')) {
-#         modelTypes[i] <- 'pa'
-#       } else if (modelTypes[i] %in% c('pb','presenceb','presence-background','presence-pseudo','presence-pseudoabsence','ppa','psa')) {
-#         modelTypes[i] <- 'pb'
-#       } else if (modelTypes[i] %in% c('ab','abundance')) {
-#         modelTypes[i] <- 'ab'
-#       } else if (modelTypes[i] %in% c('n','nominal','multinominal')) {
-#         modelTypes[i] <- 'n'
-#       } else {
-#         warning(paste('modelType',modelTypes[i],'is unknown, it is ignored!'))
-#         modelTypes[i] <- NA
-#       }
-#     }
-#     m@modelTypes <- modelTypes
-#   }
-#     
-#   #-------
-#   if (is.list(fitParams)) {
-#     n <- names(fitParams)
-#     if (is.null(n)) stop('fitParams is not appropriately defined; example: list(formula="standard.formula",data="sdmDataFrame")')
-#     m@fitParams <- fitParams
-#   } else stop('fitParams should be a list')
-#   #------
-#   if (!is.null(fitSettings)) {
-#     if (!is.list(fitSettings)) stop('fitSettings should be a list!')
-#     n <- names(fitSettings)
-#     if (is.null(n)) stop('fitSettings is not appropriately defined; example: list(family=link(binomial),ntrees=1000)')
-#     if ('' %in% n) {
-#       w <- which(n == '')
-#       for (ww in w) {
-#         if (is.character(n[ww])) names(fitSettings)[ww] <- n[w]
-#         else stop('fitSettings is not appropriately defined; example: list(family=link(binomial),ntrees=1000)')
-#       }
-#     }
-#     m@fitSettings <- fitSettings
-#   }
-#   #------
-#   if (!is.null(settingRules)) {
-#     if (!is.function(settingRules)) stop('settingRules should be a function!')
-#     m@settingRules <- settingRules
-#   }
-#   #-----
-#   if (exists(as.character(substitute(fitFunction)),mode='function') || exists(as.character(substitute(fitFunction)), envir = asNamespace('sdm'), inherits = FALSE)) {
-#     if (class(substitute(fitFunction)) == 'name') {
-#       fn <- as.character(substitute(fitFunction))
-#       if (environmentName(environment(fitFunction)) == "R_GlobalEnv") {
-#         # assign to the environment in the container of methods!
-#         if (is.null(m@.temp.env)) m@.temp.env <- new.env()
-#         assign(fn,fitFunction,envir = m@.temp.env) ####
-#         m@packages <- unique(c(m@packages,'.temp'))
-#         # when environment if attached, the conflict with the existing object in .GlobalEnv should be resolved!
-#       } 
-#       m@fitFunction <- eval(parse(text=paste("function(params) {do.call(",fn,",params)}")))
-#       
-#     } else if (class(substitute(fitFunction)) == 'call') {
-#       if (environmentName(environment(fitFunction)) == "R_GlobalEnv" || environmentName(environment(fitFunction)) == "sdm") {
-#         if (is.null(m@.temp.env)) m@.temp.env <- new.env()
-#         if (!paste(m@name,'.fit',sep='') %in% ls(envir=m@.temp.env)) fn <-paste(m@name,'.fit',sep='') ####
-#         else stop('the user defined function in fitFunction cannot be registered because an object with a similar name exists in the container!')
-#         
-#         assign(fn,fitFunction,envir = m@.temp.env) ####
-#         m@packages <- unique(c(m@packages,'.temp'))
-#       } else {
-#         if (as.character(substitute(fitFunction))[1] == "::") fn <- as.character(substitute(fitFunction))[3]
-#         else stop('fitFunction cannot be identified!')
-#       } 
-#       m@fitFunction <- eval(parse(text=paste("function(params) {do.call(",fn,",params)}")))
-#     } else stop('fitFunction cannot be identified!')
-#     
-#   } else if (exists(as.character(substitute(fitFunction)), envir = asNamespace('sdm'), inherits = FALSE)) {
-#     fn <- as.character(substitute(fitFunction))
-#     m@fitFunction <- eval(parse(text=paste("function(params) {do.call(",fn,",params)}")))
-#   } else stop(paste("Function",as.character(substitute(fitFunction)),"is not found!"))
-#   #---------
-#   
-#   if (!is.null(predictFunction)) {
-#     if (exists(as.character(substitute(predictFunction)),mode='function') || exists(as.character(substitute(predictFunction)), envir = asNamespace('sdm'), inherits = FALSE)) {
-#       
-#       if (class(substitute(predictFunction)) == 'name') {
-#         fn <- as.character(substitute(predictFunction))
-#         if (environmentName(environment(predictFunction)) == "R_GlobalEnv" ) {
-#           # assign to the environment in the container of methods!
-#           if (is.null(m@.temp.env)) m@.temp.env <- new.env()
-#           assign(fn,predictFunction,envir = m@.temp.env) ####
-#           m@packages <- unique(c(m@packages,'.temp'))
-#           # when environment if attached, the conflict with the existing object in .GlobalEnv should be resolved!
-#         } 
-#         m@predictFunction <- eval(parse(text=paste("function(params) {do.call(",fn,",params)}")))
-#         
-#       } else if (class(substitute(predictFunction)) == 'call') {
-#         if (environmentName(environment(predictFunction)) == "R_GlobalEnv" || environmentName(environment(predictFunction)) == "sdm") {
-#           if (is.null(m@.temp.env)) m@.temp.env <- new.env()
-#           if (!paste(m@name,'.predict',sep='') %in% ls(envir=m@.temp.env)) fn <-paste(m@name,'.predict',sep='') ####
-#           else stop('the user defined function in predictFunction cannot be registered because an object with a similar name exists in the container!')
-#           assign(fn,predictFunction,envir = m@.temp.env) ####
-#           m@packages <- unique(c(m@packages,'.temp'))
-#         } else {
-#           if (as.character(substitute(predictFunction))[1] == "::") fn <- as.character(substitute(predictFunction))[3]
-#           else stop('predictFunction cannot be identified!')
-#         } 
-#         
-#         m@predictFunction <- eval(parse(text=paste("function(params) {do.call(",fn,",params)}")))
-#       } else if (exists(as.character(substitute(predictFunction)), envir = asNamespace('sdm'), inherits = FALSE)) {
-#         fn <- as.character(substitute(predictFunction))
-#         m@predictFunction <- eval(parse(text=paste("function(params) {do.call(",fn,",params)}")))
-#       } else stop('predictFunction cannot be identified!')
-#       
-#     } else stop(paste("Function",as.character(substitute(predictFunction)),"is not found!"))
-#   
-#     if (!is.null(predictParams)) {
-#       if (is.list(predictParams)) {
-#         n <- names(predictParams)
-#         if (is.null(n)) stop('predictParams is not appropriately defined; example: list(newdata="sdmDataFrame")')
-#         m@predictParams <- predictParams
-#       } else stop('predictParams should be a list')
-#     }
-#     if (!is.null(predictSettings)) {
-#       if (is.list(predictSettings)) m@predictSettings <- predictSettings
-#       else stop('predictSettings should be a list!')
-#     }
-#   }
-#  #-------- 
-#   if (!is.null(tuneParams)) {
-#     if (!is.list(tuneParams)) stop('tuneParams should be a list; example: list(ntrees=seq(500,3000,by=200))')
-#     n <- names(tuneParams)
-#     if (is.null(n)) stop('tuneParams is not appropriately defined; example: list(ntrees=seq(500,3000,by=200))')
-#     m@tuneParams <- tuneParams
-#   } 
-#   #------------  
-#   if (inherits(metadata,'.Metadata')) m@metadata <- metadata
-#   else m@metadata <- .newMetadata(...)
-#   
-#   m
-# }
-
-#-----
+#--------
 
 .update.sdmCorrelativeMethod <- function(m,...) {
   name=NULL;packages=NULL;modelTypes=NULL;fitParams=NULL;fitSettings=NULL;settingRules=NULL;fitFunction=NULL;predictParams=NULL;predictSettings=NULL;predictFunction=NULL;tuneParams=NULL;metadata=NULL
@@ -480,7 +333,7 @@ setMethod('getmethodNames', signature(w='ANY'),
   }
   #-----
   
-  if (class(fitFunction) == "character") {
+  if (inherits(fitFunction,"character")) {
     if (length(strsplit(fitFunction,'::')[[1]]) == 2) fitFunction <- strsplit(fitFunction,'::')[[1]][2]
     
     if (exists(fitFunction,mode='function')) {
@@ -493,7 +346,7 @@ setMethod('getmethodNames', signature(w='ANY'),
         # when environment if attached, the conflict with the existing object in .GlobalEnv should be resolved!
       }
       m@fitFunction <- eval(parse(text=paste("function(params) {do.call(",fitFunction,",params)}")))
-    } else if (length(strsplit(fitFunction,':::')[[1]]) == 2 && class(eval(parse(text=fitFunction))) == 'function') {
+    } else if (length(strsplit(fitFunction,':::')[[1]]) == 2 && inherits(eval(parse(text=fitFunction)),'function')) {
       if (!exists(strsplit(fitFunction,':::')[[1]][2],mode='function')) {
         m@fitFunction <- eval(parse(text=paste("function(params) {do.call(",strsplit(fitFunction,':::')[[1]][2],",params)}")))
       } else {
@@ -507,7 +360,7 @@ setMethod('getmethodNames', signature(w='ANY'),
       m@fitFunction <- eval(parse(text=paste("function(params) {do.call(",fitFunction,",params)}")))
     } else stop('fitFunction cannot be identified!')
     
-  } else if (class(fitFunction) == 'function') {
+  } else if (inherits(fitFunction,'function')) {
     if (is.null(m@.temp.env)) m@.temp.env <- new.env()
     if (!paste(m@name,'.fit',sep='') %in% ls(envir=m@.temp.env)) fn <-paste(m@name,'.fit',sep='') ####
     else stop('the user defined function in fitFunction cannot be registered because an object with a similar name exists in the container!')
@@ -518,7 +371,7 @@ setMethod('getmethodNames', signature(w='ANY'),
   #---------
   
   if (!is.null(predictFunction)) {
-    if (class(predictFunction) == "character") {
+    if (inherits(predictFunction,"character")) {
       if (length(strsplit(predictFunction,'::')[[1]]) == 2) predictFunction <- strsplit(predictFunction,'::')[[1]][2]
       if (exists(predictFunction,mode='function')) {
         if (environmentName(environment(get(predictFunction))) == "R_GlobalEnv") {
@@ -529,7 +382,7 @@ setMethod('getmethodNames', signature(w='ANY'),
           # when environment if attached, the conflict with the existing object in .GlobalEnv should be resolved!
         }
         m@predictFunction <- eval(parse(text=paste("function(params) {do.call(",predictFunction,",params)}")))
-      } else if (length(strsplit(predictFunction,':::')[[1]]) == 2 && class(eval(parse(text=predictFunction))) == 'function') {
+      } else if (length(strsplit(predictFunction,':::')[[1]]) == 2 && inherits(eval(parse(text=predictFunction)),'function')) {
         if (!exists(strsplit(predictFunction,':::')[[1]][2],mode='function')) {
           m@predictFunction <- eval(parse(text=paste("function(params) {do.call(",strsplit(predictFunction,':::')[[1]][2],",params)}")))
         } else {
@@ -542,7 +395,7 @@ setMethod('getmethodNames', signature(w='ANY'),
       } else if (!Installed) {
         m@predictFunction <- eval(parse(text=paste("function(params) {do.call(",predictFunction,",params)}")))
       } else stop('predictFunction cannot be identified!')
-    } else if (class(predictFunction) == 'function') {
+    } else if (inherits(predictFunction,'function')) {
       if (is.null(m@.temp.env)) m@.temp.env <- new.env()
       if (!paste(m@name,'.predict',sep='') %in% ls(envir=m@.temp.env)) fn <-paste(m@name,'.predict',sep='') ####
       else stop('the user defined function in predictFunction cannot be registered because an object with a similar name exists in the container!')
